#!/bin/sh 
#++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
# COPYRIGHT (c) 2003 European Southern Observatory
# LICENSE
#
# PROJECT:   VLT Data Flow System
# AUTHOR:    Carlos Guirao
# CI NUMBER: 
# DESCRIPTION: Installs boot scripts for DFS system on Linux 
# REMARKS:     must be run as root 
#              installBoot machine-name
#
# $Id: installBoot.sh,v 1.3 2006/12/21 15:09:06 cguirao Exp $
#
#******************************************************
PATH=/sbin:/usr/sbin:/usr/bin:/bin
export PATH

OS=`uname -s`

case $OS in
  Linux) 
    BOOT_DIR=/etc/rc.d/init.d
    ;;
  *)
    echo "Unknown OS $OS"
    echo "This script is only for Linux"
    return 1
    ;;
esac


ADMIN_DIR=`dirname $0`
SCRIPT_DIR=`dirname $ADMIN_DIR`/boot

#
# Copies scripts and creates necessary links
#

function copyToBoot
{
   #
   # Check SCRIPT exist
   #
   if [ -f $SCRIPT_DIR/$SCRIPT.sh ]; then
      #
      # Check the OWNER user exist 
      #
      id $OWNER > /dev/null
      if [ $? -ne 0 ]; then  
	  exit 1
      fi

      if [ -f  $BOOT_DIR/$SCRIPT ]; then
         rm -f $BOOT_DIR/$SCRIPT
      fi
      cat $SCRIPT_DIR/$SCRIPT.sh | \
           sed -e "s/XXXXXX/$OWNER/" > $BOOT_DIR/$SCRIPT
      chmod 755   $BOOT_DIR/$SCRIPT
      chown root:root $BOOT_DIR/$SCRIPT

      #
      # Remove previous soft link copies
      #
      cd /etc
      rm -f rc?.d/*$SCRIPT

      #
      # Enable the different soft links levels in /etc/rc?.d dirs
      #
      chkconfig --level 0 $SCRIPT off
      chkconfig --level 1 $SCRIPT off
      chkconfig --level 6 $SCRIPT off
      chkconfig $SCRIPT on

      return 0
   else
      echo "$0: Script $SCRIPT_DIR/$SCRIPT.sh does not exist"
      return 1
   fi
}

case $1 in
'netperf')
	OWNER=root
	SCRIPT=netperf
  	copyToBoot
        grep -c netperf /etc/services
        if [ $? -ne 0 ]; then 
           echo "netperf		12865/tcp" >> /etc/services
        fi
	;;
'dfslogd')
	OWNER=root
	SCRIPT=dfslogd
  	copyToBoot
	;;
'msql2d')
	OWNER=quality
	SCRIPT=msql2d
	rm -f /opt/msql2/bin/start-msql2d
	cp $SCRIPT_DIR/start-msql2d.sh /opt/msql2/bin/start-msql2d
	chown quality:vlt  /opt/msql2/bin/start-msql2d
	chmod 750 /opt/msql2/bin/start-msql2d
  	copyToBoot
	;;
'olasDfs')
	OWNER=archeso
	SCRIPT=olasDfs
  	copyToBoot
	;;
'pipelineDfs')
	OWNER=pipeline
	SCRIPT=pipelineDfs
  	copyToBoot
	;;
'ccsLite')
	OWNER=vlt
	SCRIPT=ccsLite
  	copyToBoot
        ;;
'vcsolac')
	if [ -z "$2" ]; then  
          echo "Usage: $0 vcsolac <owner> (e.g.: cam,fors,isaac)"
	  exit 1
	fi
	OWNER=$2
	SCRIPT=vcsolac
  	copyToBoot
	;;
*)
	echo "$0: unknown boot script $1"
	echo "Usage: $0 script"
	echo "where script is: vcsolac, ccsLite, pipelineDfs, olasDfs, dfslogd, msql2d"
	exit 1
	;;
esac
